Learn R Programming

conquestr (version 0.8.5)

ConQuestRout: ConQuestRout

Description

Read an ''ACER ConQuest'' rout file created by a `plot` command in 'ACER ConQuest'.

Usage

ConQuestRout(myRout)

Arguments

myRout

The location of an 'ACER ConQuest' rout file created by 'ACER ConQuest' > 5.1.4.

Value

A list containing the data objects created by 'ACER ConQuest' plot command.

Examples

Run this code
# NOT RUN {
myPlot<- ConQuestRout()
# }
# NOT RUN {
# if you run the above example you will have the points from a plot ICC command.
str(myPlot)
# }

Run the code above in your browser using DataLab