Learn R Programming

conquestr (version 0.9.96)

ConQuestSys: ConQuestSys

Description

Read an ''ACER ConQuest'' system file created by a `put` command in 'ACER ConQuest'. The system file must not be compressed. Use the option `compressed=no`` in the put command within 'ACER ConQuest'.

Usage

ConQuestSys(myCqs)

Value

A list containing the data objects created by 'ACER ConQuest'.

Arguments

myCqs

The location of an uncompressed 'ACER ConQuest' system file created by 'ACER ConQuest' > 4.30.2.

Examples

Run this code
mySysData<- ConQuestSys()
myEx1SysData<- ConQuestSys(myCqs = system.file("extdata", "mysysfile.cqs", package = "conquestr"))
if (FALSE) {
# if you run the above example this will return your original 'ACER ConQuest' syntax.
cat(unlist(myEx1SysData$gCommandHistory))
}

Run the code above in your browser using DataLab