Learn R Programming

conquestr (version 0.8.5)

ItemDfStdZMerge: ItemDfStdZMerge

Description

Calculates Z test on the common items from 2 data frames returned from `conquestr::ItemDfStdZ`.

Usage

ItemDfStdZMerge(myDf1, myDf2, mySuffixes)

Arguments

myDf1

a data frame.

myDf2

a data frame.

mySuffixes

a vector of strings specifying the names for the two groups being analysed, e.g., if the two system files are an analysis of boys and girls, the vector may be `c(_male", "_female")`.

Value

a data frame.

See Also

conquestr::sysToItemDifDf()