Learn R Programming

conquestr (version 1.0.7)

ReadSys: ReadSys

Description

Internal function to read an 'ACER ConQuest' system file. Called by conquestr::ConQuestSys.

Usage

ReadSys(myFile)

Value

A list containing the data objects created by 'ACER ConQuest'.

Arguments

myFile

An 'ACER ConQuest' system file created by the put command in 'ACER ConQuest'. The put command must use the option compressed = no.

See Also

conquestr::ConQuestSys()