Learn R Programming

conquestr (version 0.8.5)

createConQuestProject: createConQuestProject

Description

creates a standard folder structure to work with 'ACER ConQuest' Projects.

Usage

createConQuestProject(prefix = getwd(), ...)

Arguments

prefix

a valid file path where to create project folders.

...

optional params, including "setDebug"

Value

Boolean TRUE.

Examples

Run this code
# NOT RUN {
createConQuestProject()
# }

Run the code above in your browser using DataLab