Learn R Programming

conquestr (version 0.9.96)

fmtCqItanalSmry: fmtCqItanalSmry

Description

internal function to produce formatted itanal summary statistics seen at the end of a ConQuest itanal. Note that this function is called by `fmtCqItanal` and would not usually be called by the user. The returned table uses the library kable and will be formatted based on the users settings.

Usage

fmtCqItanalSmry(cqItanalSmry, valueDecPlace)

Value

A data frame.

Arguments

cqItanalSmry

A single table in a cqItanal object (an element of type data.frame in a list of class "cqItanal".