Learn R Programming

conquestr (version 0.9.96)

getCqData: getCqData

Description

Get data objects from an R object of class ConQuestSys. This function returns person IDs, response data, case estimates, regression and weight data. Each data type is stored as a data frame, and each data frame is a named element of a list. 1. PID, 2. Responses, 3. Estimates, 4. Regression.

Usage

getCqData(mySys)

Value

A List of data frames.

Arguments

mySys

An R object of class ConQuestSys, returned by the function conquestr::ConQuestSys

See Also

conquestr::ConQuestSys()

Examples

Run this code
mySys <- ConQuestSys()
myData <- getCqData(mySys)

Run the code above in your browser using DataLab