Learn R Programming

conquestr (version 0.8.5)

getCqParams: getCqParams

Description

creates a data frame representation of the parameters of the model, including both estimated and constrained parameters. Parameters are either freely estimated ('ParamType' == 0) or constrained ('ParamType' == 0). Parameters are indexed (0 offset) by the column 'ParamNumber'. There is a seperate index for free and constrained parameters.

Usage

getCqParams(myCqs)

Arguments

myCqs

A system file.

Value

A data frame.

Examples

Run this code
# NOT RUN {
getCqParams(ConQuestSys())
# }

Run the code above in your browser using DataLab