Learn R Programming

conquestr (version 0.9.96)

getCqParams2: getCqParams2

Description

returns a list of data frames, one for each term in the model. The data frames include the the estimate, location constraint, or anchored value for each parameter. The standard error of estimated parameters is also included if it has been estimated. The fit (un/weighted MNSQ, sometimes called outfit and infit) of all parameters is alre included if has been estimated.

Usage

getCqParams2(myCqs)

Value

A list of data frames of length `gTerms`.

Arguments

myCqs

A system file.

Examples

Run this code
if (FALSE) {
getCqParams2(ConQuestSys())
}

Run the code above in your browser using DataLab