A character String.
Should the test information be calculated empirically ("empirical" - default) or analytically using moments of distribution ("approx").
minTheta
The smallest value of ability PDF to plot.
maxTheta
The largest value of ability PDF to plot.
stepTheta
The increment to iterate over the ability PDF. Defaults to 0.01.
scaleInfo
A scaling factor to apply to the plot of tesr information.
Because ability distribution is a PDF with area one, and a test information function has area L, this can make the plot more interpretable. Defaults to 1.