Learn R Programming

conquestr (version 0.9.96)

itemInfoAtTheta: itemInfoAtTheta

Description

Calculates item information at a value of theta given a set of item parameters.

Usage

itemInfoAtTheta(myItem, theta)

Arguments

myItem

A matrix of item parameters of the structure used in `simplef`

theta

a number.

Examples

Run this code
anItem<-  matrix(c(0,0,0,1,1,0), nrow = 2, byrow = TRUE)
itemInfoAtTheta(anItem, 0)

Run the code above in your browser using DataLab