Learn R Programming

conquestr (version 0.9.96)

itemResp: itemResp

Description

Returns a probabilistic item response, given one ability and one item (a matrix k categories by three (categor score, delta dot, tau).

Usage

itemResp(myAblty, myItem)

Value

A numeric score, usually an integer in the range 0, 1, 2, ..., k-1.

Arguments

myAblty

A numeric ability.

myItem

A single item (a matrix k categories by three (categor score, delta dot, tau).

Examples

Run this code
myItem<- matrix(c(0, 0, 0, 1, 1, 0), ncol = 3, byrow = TRUE)
itemResp(0, myItem)

Run the code above in your browser using DataLab