Learn R Programming

conquestr (version 0.9.96)

plotItemMap: plotItemMap

Description

Creates a plot (ggplot2 object) of item parameter estimates and abilities on latent trait. Note this is not for use with `rout` files. See the method method plotRout.itemMap to the generic function `plotRout`

Usage

plotItemMap(mySys, myDims = "D1", abilityType = "PV", ...)

Value

A ggplot2 object.

Arguments

mySys

An 'ACER ConQuest' system file object created using the conquestr::ConQuestSys function.

myDims

A string specifying which specific dimensions should be included. The default is "D1", Specific dimensions are specified by the label "D1" for dimensions 1 etc. Alternatively, you can specify myDims = "all", though what this produces is not currenlty supported.

abilityType

What kind of person ability estimate should be used? Defaults to plausible values. Alternatievly WLE, MLE, EAP.

...

Optional arguments, mostly for debugging, e.g., `setDebug = TRUE` will print temporary data frames.

Examples

Run this code
mySys1<- ConQuestSys()
myItemMap<- plotItemMap(mySys1, myDims = "all")
if (FALSE) {
# if you run the above example you will have the plot in the object `myItemMap`.
plot(myItemMap)
}

Run the code above in your browser using DataLab