Learn R Programming

conquestr (version 1.0.7)

plotModelExp: plotModelExp

Description

Creates a plot of a model-implied expected score curve. Note this is not for use with rout files. See the generic function plotRout for plotting rout files.

Usage

plotModelExp(items, range = c(-6, 6), by = 0.1)

Value

A ggplot2 object.

Arguments

items

List of one or more matricies of item parameters.

range

Lower and upper bounds to plot over (defaults to c(-6, 6).

by

Increment to the sequence along `range``.

Examples

Run this code
myItem <- matrix(
  c(
    0, 0, 0, 1,
    1, 1, 0, 1
  ),
  ncol = 4, byrow=TRUE
)
myPlot <- plotModelExp(list(myItem))

Run the code above in your browser using DataLab