Learn R Programming

conquestr (version 0.9.96)

plotRout: plotRout

Description

generates a plot from an 'ACER ConQuest' Rout file. use `ConQuestRout` to read in an Rout file created by a `plot` command in 'ACER ConQuest'.

Usage

plotRout(myRout, ...)

# S3 method for TestInfo plotRout(myRout, ...)

# S3 method for InformationWithLatentDist plotRout(myRout, ...)

# S3 method for ICC plotRout(myRout, ...)

# S3 method for MCC plotRout(myRout, ...)

# S3 method for default plotRout(myRout, ...)

Value

A ggplot2 object.

Arguments

myRout

an R object created by the `ConQuestRout` function.

...

additional arguments passed into plotting functions (e.g., `plotZero = TRUE` to control whether the 0 category is plotted in ICC and MCC).

Examples

Run this code
myPlot<- plotRout(ConQuestRout())
if (FALSE) {
# if you run the above example you will have a ggplot2 object, using the default Rout file (an ICC).
str(myPlot)
}
## to see why we import this, see https://ggplot2.tidyverse.org/articles/ggplot2-in-packages.html

Run the code above in your browser using DataLab