Learn R Programming

conquestr (version 1.0.7)

pvMeanVar: pvMeanVar

Description

Applies the law of total variance (EVEs law) to calculate the mean and varinace of a set of PVs for one dimension.

Usage

pvMeanVar(myData)

Value

A list containing the mean and variaince of the PVs.

Arguments

myData

A matrix of PVs for one dimension: m PVs by n cases.