Learn R Programming

conquestr (version 1.0.7)

simplep: simplep

Description

returns response probabilities for each reponse category of an item at a given value of theta.

Usage

simplep(theta, i_params)

Value

a k x 1 matrix of response probabilities evaluated at theta.

Arguments

theta

a scalar value of theta.

i_params

an item design matrix that is of size response categories (k) by three. The three columns are:

  • column one is scoring values, usually from 0 to k.

  • column two is the delta dot parameter repeated k times (the average difficulty of the item)

  • column three is the tau (step) parameter where for k = 1, tau = 0, and for k >= 2, subsequent entries are deviations from delta dot.

  • column four is the discrimination paramter ("a")

Examples

Run this code
myTheta <- 0
myDelta <- 1.5
a <- 1.5
k <- 3
itemParamX <- seq(0, k-1, 1)
itemParamD <- rep(myDelta, k)
itemParamT <- c(0, -0.5, 0.5)
itemParamA <- rep(a, k)
itemParam <- cbind(itemParamX, itemParamD, itemParamT, itemParamA)
colnames(itemParam)<- c("x", "d", "t", "a")
myProbs <- simplep(myTheta, itemParam)

Run the code above in your browser using DataLab