Learn R Programming

conquestr (version 0.9.96)

testInfoAtTheta: testInfoAtTheta

Description

Calculates test information at a value of theta given a list of many sets of item parameters.

Usage

testInfoAtTheta(myItems, theta)

Arguments

myItems

A list of matrices of item parameters of the structure used in `simplef`

theta

a number.

Examples

Run this code
anItem<-  matrix(c(0,0,0,1,1,0), nrow = 2, byrow = TRUE)
testInfoAtTheta(list(anItem), 0)

Run the code above in your browser using DataLab