Learn R Programming

conquestr (version 0.9.96)

testInfoOverTheta: testInfoOverTheta

Description

Calculates test information over a range of theta given a list of many sets of item parameters. Returns a data frame with item information at a discrete set of values of theta - useful for plotting item information functions.

Usage

testInfoOverTheta(myItems, minTheta = -6, maxTheta = 6, stepTheta = 0.1)

Arguments

myItems

a list of item parameters of the structure used in `simplef`

minTheta

The smallest value of ability PDF to plot.

maxTheta

The largest value of ability PDF to plot.

stepTheta

The increment to iterate over the ability PDF. Defaults to 0.01.

Examples

Run this code
anItem<-  matrix(c(0,0,0,1,1,0), nrow = 2, byrow = TRUE)
testInfoOverTheta(list(anItem))

Run the code above in your browser using DataLab