Return score (O-E) at theta. Used in estimation of theta by minimising _raw score - expected score_ at theta
thetaScore(theta, responses, itemParams, perfAdjust = 0.3)a double, the score (O-E) at theta.
a scalar value of theta.
a vector of item responses for one case (can contain NA). Responses are in the same order as `items`
a list of item designs (each used in a call to `simplef`). Must be of same length as `responses`.
the correction factor for zeros and perfects to be add/subtracted from the raw score.