powered by
Read an ''ACER ConQuest'' rout file created by a `plot` command in 'ACER ConQuest'.
ConQuestRout(myRout)
The location of an 'ACER ConQuest' rout file created by 'ACER ConQuest' > 5.1.4.
A list containing the data objects created by 'ACER ConQuest' plot command.
# NOT RUN { myPlot<- ConQuestRout() # } # NOT RUN { # if you run the above example you will have the points from a plot ICC command. str(myPlot) # }
Run the code above in your browser using DataLab