powered by
Internal function to read an 'ACER ConQuest' system file. Called by conquestr::ConQuestSys.
ReadSys(myFile)
A list containing the data objects created by 'ACER ConQuest'.
An 'ACER ConQuest' system file created by the put command in 'ACER ConQuest'. The put command must use the option compressed = no.
put
compressed = no
conquestr::ConQuestSys()