powered by
creates a standard folder structure to work with 'ACER ConQuest' Projects.
createConQuestProject(prefix = getwd(), ...)
a valid file path where to create project folders.
optional params, including "setDebug"
Boolean TRUE.
# NOT RUN { createConQuestProject() # }
Run the code above in your browser using DataLab