internal function to produce formatted itanal summary statistics seen at the end of a ConQuest itanal. Note that this function is called by `fmtCqItanal` and would not usually be called by the user. The returned table uses the library kable and will be formatted based on the users settings.
fmtCqItanalSmry(cqItanalSmry, valueDecPlace)A data frame.
A single table in a cqItanal object (an element of type data.frame in a list of class "cqItanal".