Get data objects from an R object of class ConQuestSys.
This function returns person IDs, response data, case estimates, regression and weight data.
Each data type is stored as a data frame, and each data frame is a named element of a list.
1. PID, 2. Responses, 3. Estimates, 4. Regression.