Calculate test information function, given a vector of item difficulties and a vector of abilities.
Returns a data frame that can be easily plotted.
Usage
infoFunc(
myItems,
myAbilities,
type = "empirical",
minTheta = NA,
maxTheta = NA,
stepTheta = NA
)
Value
A data frame.
Arguments
myItems
A vector of item deltas.
myAbilities
A vector of person abilities.
type
A character String.
Should the test information be calculated empirically ("empirical" - default) or analytically using moments of distribution ("approx").
minTheta
The smallest value of ability PDF to plot.
maxTheta
The largest value of ability PDF to plot.
stepTheta
The increment to iterate over the ability PDF. Defaults to 0.01.