powered by
Calculates item information at a value of theta given a set of item parameters.
itemInfoAtTheta(myItem, theta)
A matrix of item parameters of the structure used in `simplef`
a number.
anItem<- matrix(c(0,0,0,1,1,0), nrow = 2, byrow = TRUE) itemInfoAtTheta(anItem, 0)
Run the code above in your browser using DataLab