powered by
Returns a probabilistic item response, given one ability and one item (a matrix k categories by three (categor score, delta dot, tau).
itemResp(myAblty, myItem)
A numeric score, usually an integer in the range 0, 1, 2, ..., k-1.
A numeric ability.
A single item (a matrix k categories by three (categor score, delta dot, tau).
myItem<- matrix(c(0, 0, 0, 1, 1, 0), ncol = 3, byrow = TRUE) itemResp(0, myItem)
Run the code above in your browser using DataLab