returns the MLE for each case and asymptotic variance given a _fixed_ set of item parameters. This is done by finding the root of the distance between the observed and expected score at theta. That is, the location where O-E = 0.
mleCalc(responses, itemParams, ...)a data frame.
a data frame made up of rows of vectors of item responses, one for each case.
a list of item designs (each used in a call to `simplef`). Must be of same length as `responses`.
optional arguments, e.g., perfAdj.