myItemHelper: myAbilitiesHelper
Description
helper function to return attributes of vector of item deltas for use in information function and WI.
Usage
myItemHelper(myWhat = "ok", myItems = NA)
Value
A Boolean or a double.
Arguments
- myWhat
A character string indicating what to check.
- myItems
A numeric vector of item deltas.