powered by
Perturbs response probabilities.
perturbProbs(myProbs, perturbP)
A matrix.
A matrix of size n persons by i items. Each element is a response probability or expected scores for the person by item combination.
n
i
A list of length i of response probabilities from n persons * i items.
myExProbs <- matrix(rnorm(100, 0, 1), 10, 10) myExPerturb <- list(data.frame(item = 1, type = "flat", pivot = 0.5, factor = 25)) myProbs <- perturbProbs(myProbs = myExProbs, perturbP = myExPerturb)
Run the code above in your browser using DataLab