Description
generates a plot from a history object. Use getCqHist to create a history object from an 'ACER ConQuest' system file.
Usage
plotCqHist(myHist, centre = TRUE, params = c("all"), legend = FALSE)Arguments
- myHist
an R object created by the getCqHist function.
- centre
a Boolean representing whether the iteration history should be mean centred (within parameter).
This is helpful for plots that include all parameters to ensure the Y axis is sensible. Consider a plot with raw values of the Likelihood and item parameters on it.
- params
A vector of which params to plot. Must be one or more of "all", "Likelihood", "Beta", Variance", "Xsi", "Tau".
- legend
Should a legend be plotted?.
Examples
Run this codeif (FALSE) {
myHistPlot <- plotCqHist(getCqHist(ConQuestSys()))
}
Run the code above in your browser using DataLab