Creates a plot (ggplot2 object) of item parameter estimates and abilities on latent trait.
Note this is not for use with `rout` files. See the method method plotRout.itemMap to the generic function `plotRout`
Usage
plotItemMap(mySys, myDims = "D1", ...)
Arguments
mySys
An 'ACER ConQuest' system file object created using the conquestr::ConQuestSys function.
myDims
A string specifying which specific dimensions should be included. The default is "D1", Specific dimensions are specified by the label "D1" for dimensions 1 etc.
Alternatively, you can specify myDims = "all", though what this produces is not currenlty supported.
...
Optional arguments, mostly for debugging, e.g., `setDebug = TRUE` will print temporary data frames.
# NOT RUN {mySys1<- ConQuestSys()
myItemMap<- plotItemMap(mySys1, myDims = "all")
# }# NOT RUN {# if you run the above example you will have the plot in the object `myItemMap`.plot(myItemMap)
# }