Learn R Programming

conquestr (version 0.8.5)

plotRout: plotRout

Description

generates a plot from an 'ACER ConQuest' Rout file. use `ConQuestRout` to read in an Rout file created by a `plot` command in 'ACER ConQuest'.

Usage

plotRout(myRout)

# S3 method for InformationWithLatentDist plotRout(myRout)

# S3 method for ICC plotRout(myRout)

# S3 method for default plotRout(myRout)

Arguments

myRout

an R object created by the `ConQuestRout` function.

Value

A ggplot2 object.

Examples

Run this code
# NOT RUN {
myPlot<- plotRout(ConQuestRout())
# }
# NOT RUN {
# if you run the above example you will have a ggplot2 object, using the default Rout file (an ICC).
str(myPlot)
# }
# NOT RUN {
## to see why we import this, see https://ggplot2.tidyverse.org/articles/ggplot2-in-packages.html
# }

Run the code above in your browser using DataLab