powered by
Applies the law of total variance (EVEs law) to calculate the mean and varinace of a set of PVs for one dimension.
pvMeanVar(myData)
A list containing the mean and variaince of the PVs.
A matrix of PVs for one dimension: m PVs by n cases.