Read an R object of class ConQuestSys and create a labelled representation of the B matrix (scoring matrix). This maps item response catagories to items and dimensions. Returns long data frame, where items are duplicated if they are in many dimnsions.
Usage
sysToBMatrixDf(mySys, applyLabels = TRUE)
Arguments
mySys
An R object of class ConQuestSys, returned by the function conquestr::ConQuestSys
applyLabels
A bool indicating whether labels (e.g., dimension labels) should be appended.
# NOT RUN {myBMatrix<- sysToBMatrixDf(ConQuestSys())
# }# NOT RUN {# if you run the above example you will have the B Matrix from the example system file.str(myBMatrix)
# }