powered by
Calculates test information at a value of theta given a list of many sets of item parameters.
testInfoAtTheta(myItems, theta)
A list of matrices of item parameters of the structure used in `simplef`
a number.
anItem<- matrix(c(0,0,0,1,1,0), nrow = 2, byrow = TRUE) testInfoAtTheta(list(anItem), 0)
Run the code above in your browser using DataLab